###########################################################################################
################################ RSFs - final scripts caribou #############################
###########################################################################################


### Library upload

library(lmerTest)
library(car)
library(foreign)
library(stringr)
library(stringi)
library(lme4)


backup = data_rsf_caribou


############################################################################
################################# SPRING ###################################
############################################################################

# Import database

data_spring <- read_excel(file.choose(), 1)

data_spring$YEAR_rsf = data_spring$YEAR_suivi # recreate variable  YEAR_rsf in characters
data_spring$YEAR_rsf = as.character(data_spring$YEAR_rsf) 
str(data_spring)



sum(sum(data_spring$L_Decid_Mixt_Mature),
sum(data_spring$L_OldMatForest),
sum(data_spring$L_Other),
sum(data_spring$L_Perturb_0_5),
sum(data_spring$L_Perturb_6_20),
sum(data_spring$L_Regeneration),
sum(data_spring$L_Wetlands),
sum(data_spring$L_YgMatForest))

essai1=subset(data_spring, L_YgMatForest==1)
essai2=subset(data_spring, L_OldMatForest==1)


##### Verify frequency distributions of independent variables

data_spring_0 = subset(data_spring, presence==0)
data_spring_1 = subset(data_spring, presence==1)

hist(data_spring_0$RISK_LOUPS)
boxplot(data_spring_0$RISK_LOUPS)
hist(data_spring_0$RISK_OURS)
boxplot(data_spring_0$RISK_OURS)

hist(data_spring_1$RISK_LOUPS)
boxplot(data_spring_1$RISK_LOUPS)
hist(data_spring_1$RISK_OURS)
boxplot(data_spring_1$RISK_OURS)


##### Verify that we have data for each levels of random effects

length(table(data_spring$IDENT_YEAR)) # 139 ID-year

RISK_SPRING=glmer(presence~RISK_LOUPS+RISK_OURS+YEAR_no+RISK_LOUPS:YEAR_no+RISK_OURS:YEAR_no+(1+RISK_LOUPS:YEAR_no|IDENT)+(1+RISK_OURS:YEAR_no|IDENT)+(1|YEAR_rsf),family=binomial,data=data_spring) # Modele complet pr visualiser les random effet

table(data_spring$IDENT,data_spring$YEAR_no) # No individual in problem


# CHOOSING A REF CATEGORY : L_Decid_Mixt_Mature for spring (UD close to 1, well distributed), L_Perturb_6_20 for caving (UD close to 1, well distributed), L_OldMatForest for calf vulnerability (UD close to 1, well distributed) and L_YgMatForest for winter (UD closer to 1 for L_Perturb_0_5 but a rare category, so we chose L_YgMatForest 2nd closest to 1 but well distributed). 

##### CANDIDATE MODELS

# REF CATEGORY : L_Decid_Mixt_Mature

# Model A (2 variables of risk only)
RISK_SPRING_A=glmer(presence~RISK_LOUPS+RISK_OURS+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_spring)

# Model B (habitat classes only)
RISK_SPRING_B=glmer(presence~L_OldMatForest+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_spring)

# Model C (habitat and wolf risk)
RISK_SPRING_C=glmer(presence~L_OldMatForest+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+RISK_LOUPS+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_spring)

# Model D (habitat and bear risk)
RISK_SPRING_D=glmer(presence~L_OldMatForest+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+RISK_OURS+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_spring)

# Model E (habitat and both risks)
RISK_SPRING_E=glmer(presence~L_OldMatForest+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+RISK_LOUPS+RISK_OURS+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_spring)

# Model F (habitat and interaction with wolf risk)
RISK_SPRING_F=glmer(presence~L_OldMatForest+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+RISK_LOUPS+RISK_OURS+YEAR_no+RISK_LOUPS:YEAR_no+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_spring)

# Model G (habitat and interaction with bear risk)
RISK_SPRING_G=glmer(presence~L_OldMatForest+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+RISK_LOUPS+RISK_OURS+YEAR_no+RISK_OURS:YEAR_no+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_spring)

# Model H (habitat and interactions with both risks)
RISK_SPRING_H=glmer(presence~L_OldMatForest+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+RISK_LOUPS+RISK_OURS+YEAR_no+RISK_LOUPS:YEAR_no+RISK_OURS:YEAR_no+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_spring)

summary(RISK_SPRING_H)
str(data_spring)


AICc_SPRING = model.sel(RISK_SPRING_A,RISK_SPRING_B,RISK_SPRING_C,RISK_SPRING_D,RISK_SPRING_E,RISK_SPRING_F,RISK_SPRING_G,RISK_SPRING_H, rank = AICc)

AICc_SPRING = rownames_to_column(AICc_SPRING,var = "model")

write_xlsx(AICc_SPRING, path="AICc_SPRING.xlsx")

summary(RISK_SPRING_H)


##### BEST RANKED MODEL

str(data_spring)

RISK_SPRING_H=glmer(presence~L_OldMatForest+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+RISK_LOUPS+RISK_OURS+YEAR_no+RISK_LOUPS:YEAR_no+RISK_OURS:YEAR_no+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_spring) # Meilleur modele. Pour la periode spring, ca converge pas avec optimx, donc je le run sans

save(RISK_SPRING_H, file = "RISK_SPRING_H.RData") # function to save the model
load("RISK_SPRING_H.RData") # function to load the model

range(data_spring$RISK_OURS)

RISK_SPRING_H_coefs <- as.data.frame(coef(summary(RISK_SPRING_H)))
RISK_SPRING_H_coefs = rownames_to_column(RISK_SPRING_H_coefs,var = "variable")
CI_spring = as.data.frame(confint(RISK_SPRING_H,method="Wald"))
CI_spring = CI_spring[-c(1:2),]
RISK_SPRING_H_coefs$CI_2.5 = CI_spring$`2.5 %`
RISK_SPRING_H_coefs$CI_97.5 = CI_spring$`97.5 %`
write_xlsx(RISK_SPRING_H_coefs, path="RISK_SPRING_H_coefs.xlsx")


##### K-FOLD CROSS VALIDATION

RISK_SPRING_H=glmer(presence~L_OldMatForest+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+RISK_LOUPS+RISK_OURS+YEAR_no+RISK_LOUPS:YEAR_no+RISK_OURS:YEAR_no+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_spring)

kfold_crossvalid(data=data_spring, nbiter=15, mod="presence~L_OldMatForest+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+RISK_LOUPS+RISK_OURS+YEAR_no+RISK_LOUPS:YEAR_no+RISK_OURS:YEAR_no+(1|IDENT)+(1|YEAR_rsf)",pourc=0.75,pres=data_spring$presence,id=as.vector(data_spring$IDENT),byid=F) # 0.943 (SD=0.006). 14 iterations sur 15 ont converge, pas d'erreur sinon

kfold_crossvalid(data=data_spring, nbiter=15, mod="presence~L_OldMatForest+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+RISK_LOUPS+RISK_OURS+YEAR_no+RISK_LOUPS:YEAR_no+RISK_OURS:YEAR_no+(1|IDENT)+(1|YEAR_rsf)",pourc=0.75,pres=data_spring$presence,id=as.vector(data_spring$IDENT),byid=T) # 0.816 (SD=0.149). 14 iterations sur 15 ont converge, pas d'erreur sinon


##### ASSUMPTIONS

# Condition 1 : binarity of dep var (ok)
# Condition 2 : linear relationship between logit(y) and each ind var (ok)
# Condition 3 : absence of outliers
# Condition 4 : no colinearity (VIFs)


plot(RISK_SPRING_H) # Condition 3


RISK_SPRING_H_sans_int=glmer(presence~L_OldMatForest+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+RISK_LOUPS+RISK_OURS+YEAR_no+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_spring) # Pour les VIFs, runner modele sans interactions

vif(RISK_SPRING_H_sans_int) # VIF MAX = 8.27 (perturb_6_20). 7.41 for oldmatforest. 6.76 for ygmatforest


RISK_SPRING_H_test=glmer(presence~L_OldMatForest+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+YEAR_no+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_spring)

vif(RISK_SPRING_H_test) # VIF max = 7.95 (perturb_6_20). 7.26 for oldmatforest. 6.53 for ygmatforest


##### VERIFICATION CONCERNING DISTRIBUTION OF BEAR LOCATIONS DURING THIS PERIOD

# RUN MODEL with locations between April 25 and May 24 only to see if estimated coefficients are similar. # Conclusion : estimates are almost the same (from 0.22 to 0.26 for interaction RISK_OURS:YEAR_no), p-value still low (< 2e-16 ***). 
str(data_spring)
test_data_spring = data_spring
test_data_spring$Date <- as.Date(test_data_spring$Timestamp)
test_data_spring$MONTHDAY<-as.numeric(format(test_data_spring$Date,"%m%d"))
table(test_data_spring$MONTHDAY)
test_data_spring = subset(test_data_spring,MONTHDAY>425)

RISK_SPRING_L_V2=glmer(presence~RISK_LOUPS+RISK_OURS+YEAR_no+RISK_LOUPS:YEAR_no+RISK_OURS:YEAR_no+(1+RISK_LOUPS+RISK_OURS|IDENT)+(1|YEAR_rsf),family=binomial,data=test_data_spring)

summary(RISK_SPRING_L)
summary(RISK_SPRING_L_V2)




#############################################################################
################################# CALVING ###################################
#############################################################################

# Import database

data_calving <- read_excel(file.choose(), 1)

data_calving$YEAR_rsf = data_calving$YEAR_suivi # recreate variable  YEAR_rsf in characters
data_calving$YEAR_rsf = as.character(data_calving$YEAR_rsf) 
str(data_calving)


sum(sum(data_calving$L_Decid_Mixt_Mature),
    sum(data_calving$L_OldMatForest),
    sum(data_calving$L_Other),
    sum(data_calving$L_Perturb_0_5),
    sum(data_calving$L_Perturb_6_20),
    sum(data_calving$L_Regeneration),
    sum(data_calving$L_Wetlands),
    sum(data_calving$L_YgMatForest))

essai1=subset(data_calving, L_YgMatForest==1)
essai2=subset(data_calving, L_OldMatForest==1)


##### Verify frequency distributions of independent variables

data_calving_0 = subset(data_calving, presence==0)
data_calving_1 = subset(data_calving, presence==1)

hist(data_calving_0$RISK_LOUPS)
boxplot(data_calving_0$RISK_LOUPS)
hist(data_calving_0$RISK_OURS)
boxplot(data_calving_0$RISK_OURS)

hist(data_calving_1$RISK_LOUPS)
boxplot(data_calving_1$RISK_LOUPS)
hist(data_calving_1$RISK_OURS)
boxplot(data_calving_1$RISK_OURS)


##### Verify that we have data for each levels of random effects

length(table(data_calving$IDENT_YEAR)) # 115 ID_YEAR

table(data_calving$IDENT,data_calving$YEAR_no) # No individual in problem


##### CANDIDATE MODELS

# REF CATEGORY : L_Perturb_6_20

# Model A (2 variables of risk only)
RISK_CALVING_A=glmer(presence~RISK_LOUPS+RISK_OURS+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_calving,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))

# Model B (habitat categories only)
RISK_CALVING_B=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_OldMatForest+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_calving,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))

# Model C (habitat et risk wolf)
RISK_CALVING_C=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_OldMatForest+RISK_LOUPS+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_calving,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))

# Model D (habitat and risk bear)
RISK_CALVING_D=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_OldMatForest+RISK_OURS+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_calving,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))

# Model E (habitat and both risks)
RISK_CALVING_E=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_OldMatForest+RISK_LOUPS+RISK_OURS+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_calving,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))

# Model F (habitat and interaction with wolf risk)
RISK_CALVING_F=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_OldMatForest+RISK_LOUPS+RISK_OURS+YEAR_no+RISK_LOUPS:YEAR_no+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_calving,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))

# Model G (habitat and interaction with bear risk)
RISK_CALVING_G=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_OldMatForest+RISK_LOUPS+RISK_OURS+YEAR_no+RISK_OURS:YEAR_no+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_calving,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))

# Modele H (habitat et interactions popu)
RISK_CALVING_H=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_OldMatForest+RISK_LOUPS+RISK_OURS+YEAR_no+RISK_LOUPS:YEAR_no+RISK_OURS:YEAR_no+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_calving,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))


library(AICcmodavg)

AICc_CALVING = model.sel(RISK_CALVING_A,RISK_CALVING_B,RISK_CALVING_C,RISK_CALVING_D,RISK_CALVING_E,RISK_CALVING_F,RISK_CALVING_G,RISK_CALVING_H, rank = AICc)

AICc_CALVING = rownames_to_column(AICc_CALVING,var = "model")

write_xlsx(AICc_CALVING, path="AICc_CALVING.xlsx")


##### BEST RANKED MODEL

str(data_calving)

RISK_CALVING_H=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_OldMatForest+RISK_LOUPS+RISK_OURS+YEAR_no+RISK_LOUPS:YEAR_no+RISK_OURS:YEAR_no+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_calving,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))

summary(RISK_SPRING_H)


save(RISK_CALVING_H, file = "RISK_CALVING_H.RData") # function to save it
load("RISK_CALVING_H.RData") # Function to load it


RISK_CALVING_H_coefs <- as.data.frame(coef(summary(RISK_CALVING_H)))
RISK_CALVING_H_coefs = rownames_to_column(RISK_CALVING_H_coefs,var = "variable")
CI_calving = as.data.frame(confint(RISK_CALVING_H,method="Wald"))
CI_calving = CI_calving[-c(1:2),]
RISK_CALVING_H_coefs$CI_2.5 = CI_calving$`2.5 %`
RISK_CALVING_H_coefs$CI_97.5 = CI_calving$`97.5 %`
write_xlsx(RISK_CALVING_H_coefs, path="RISK_CALVING_H_coefs.xlsx")


##### K-FOLD CROSS VALIDATION

RISK_CALVING_H=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_OldMatForest+RISK_LOUPS+RISK_OURS+YEAR_no+RISK_LOUPS:YEAR_no+RISK_OURS:YEAR_no+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_calving,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))

kfold_crossvalid(data=data_calving, nbiter=15, mod="presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_OldMatForest+RISK_LOUPS+RISK_OURS+YEAR_no+RISK_LOUPS:YEAR_no+RISK_OURS:YEAR_no+(1|IDENT)+(1|YEAR_rsf)",pourc=0.75,pres=data_calving$presence,id=as.vector(data_calving$IDENT),byid=F) # 0.989 (SD=0.010). 10 iterations sur 15 ont converge, pas d'erreur sinon

kfold_crossvalid(data=data_calving, nbiter=15, mod="presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_OldMatForest+RISK_LOUPS+RISK_OURS+YEAR_no+RISK_LOUPS:YEAR_no+RISK_OURS:YEAR_no+(1|IDENT)+(1|YEAR_rsf)",pourc=0.75,pres=data_calving$presence,id=as.vector(data_calving$IDENT),byid=T) # 0.890 (SD=0.095). 13 iterations sur 15 ont converge. 2 erreurs de singular fit.


##### ASSUMPTIONS

# Condition 1 : binarity of dep var (ok)
# Condition 2 : linear relationship between logit(y) and each ind var (ok)
# Condition 3 : absence of outliers
# Condition 4 : no colinearity (VIFs)

plot(RISK_CALVING_H) # Condition 3

RISK_CALVING_H_sans_int=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_OldMatForest+RISK_LOUPS+RISK_OURS+YEAR_no+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_calving,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE))) # Pour les VIFs, runner modele sans interactions

vif(RISK_CALVING_H_sans_int) # VIF MAX = 1.93



#############################################################################
################################# CALFVULN ##################################
#############################################################################

# Import database

data_calfvuln <- read_excel(file.choose(), 1)

data_calfvuln$YEAR_rsf = data_calfvuln$YEAR_suivi # recreate variable  YEAR_rsf in characters
data_calfvuln$YEAR_rsf = as.character(data_calfvuln$YEAR_rsf) 
str(data_calfvuln)


##### Verify frequency distributions of independent variables

data_calfvuln_0 = subset(data_calfvuln, presence==0)
data_calfvuln_1 = subset(data_calfvuln, presence==1)

hist(data_calfvuln_0$RISK_LOUPS)
boxplot(data_calfvuln_0$RISK_LOUPS)
hist(data_calfvuln_0$RISK_OURS)
boxplot(data_calfvuln_0$RISK_OURS)

hist(data_calfvuln_1$RISK_LOUPS)
boxplot(data_calfvuln_1$RISK_LOUPS)
hist(data_calfvuln_1$RISK_OURS)
boxplot(data_calfvuln_1$RISK_OURS)


##### Verify that we have data for each levels of random effects

length(table(data_calfvuln$IDENT_YEAR)) # 115 ID-YEAR

table(data_calfvuln$IDENT,data_calfvuln$YEAR_no) # No individual in problem


summary(RISK_SPRING_H)
summary(RISK_CALVING_H)


##### CANDIDATE MODELS

# REF CATEGORY : L_OldMatForest

# Model A (2 variables of risk only)
RISK_CALFVULN_A=glmer(presence~RISK_LOUPS+RISK_OURS+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_calfvuln,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))

# Model B (habitat classes only)
RISK_CALFVULN_B=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_calfvuln,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))

# Model C (habitat and wolf risk)
RISK_CALFVULN_C=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+RISK_LOUPS+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_calfvuln,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))

# Model D (habitat and bear risk)
RISK_CALFVULN_D=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+RISK_OURS+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_calfvuln,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))

# Model E (habitat and both risks)
RISK_CALFVULN_E=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+RISK_LOUPS+RISK_OURS+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_calfvuln,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))

# Model F (habitat and interactions with wolf risk)
RISK_CALFVULN_F=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+RISK_LOUPS+RISK_OURS+YEAR_no+RISK_LOUPS:YEAR_no+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_calfvuln,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))

# Model G (habitat and interactions with bear risk)
RISK_CALFVULN_G=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+RISK_LOUPS+RISK_OURS+YEAR_no+RISK_OURS:YEAR_no+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_calfvuln,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))

# Model H (habitat and interactions with both risks)
RISK_CALFVULN_H=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+RISK_LOUPS+RISK_OURS+YEAR_no+RISK_LOUPS:YEAR_no+RISK_OURS:YEAR_no+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_calfvuln,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))


AICc_CALFVULN = model.sel(RISK_CALFVULN_A,RISK_CALFVULN_B,RISK_CALFVULN_C,RISK_CALFVULN_D,RISK_CALFVULN_E,RISK_CALFVULN_F,RISK_CALFVULN_G,RISK_CALFVULN_H, rank = AICc)

AICc_CALFVULN = rownames_to_column(AICc_CALFVULN,var = "model")

write_xlsx(AICc_CALFVULN, path="AICc_CALFVULN.xlsx")

summary(RISK_CALFVULN_H)


##### BEST-RANKED MODEL

RISK_CALFVULN_H=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+RISK_LOUPS+RISK_OURS+YEAR_no+RISK_LOUPS:YEAR_no+RISK_OURS:YEAR_no+(1|IDENT),family=binomial,data=data_calfvuln,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE))) # NOTE : Lors de la validation croisee, il y avait des erreurs de singular fit avec le modele. Jai donc essaye de le runner sans (1|YEAR_rsf), et il n'y avait plus d'erreur de singular fit. Je choisis donc de travailler avec le modele sans (1|YEAR_rsf), et de toute facon, apres verification, les deux modeles (avec et sans) donnent exactement les memes coefficients (desfois il y a des differences a la 4e decimale pres)

summary(RISK_CALFVULN_H)

save(RISK_CALFVULN_H, file = "RISK_CALFVULN_H.RData") # function to save it
load("RISK_CALFVULN_H.RData") # function to load it


RISK_CALFVULN_H_coefs <- as.data.frame(coef(summary(RISK_CALFVULN_H)))
RISK_CALFVULN_H_coefs = rownames_to_column(RISK_CALFVULN_H_coefs,var = "variable")
CI_calfvuln = as.data.frame(confint(RISK_CALFVULN_H,method="Wald"))
CI_calfvuln = CI_calfvuln[-c(1),]
RISK_CALFVULN_H_coefs$CI_2.5 = CI_calfvuln$`2.5 %`
RISK_CALFVULN_H_coefs$CI_97.5 = CI_calfvuln$`97.5 %`
write_xlsx(RISK_CALFVULN_H_coefs, path="RISK_CALFVULN_H_coefs.xlsx")


##### K-FOLD CROSS VALIDATION

RISK_CALFVULN_H=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+RISK_LOUPS+RISK_OURS+YEAR_no+RISK_LOUPS:YEAR_no+RISK_OURS:YEAR_no+(1|IDENT),family=binomial,data=data_calfvuln,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))

kfold_crossvalid(data=data_calfvuln, nbiter=25, mod="presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+RISK_LOUPS+RISK_OURS+YEAR_no+RISK_LOUPS:YEAR_no+RISK_OURS:YEAR_no+(1|IDENT)",pourc=0.75,pres=data_calfvuln$presence,id=as.vector(data_calfvuln$IDENT),byid=F) # Il y avait erreur de singular fit avec le modele complet, mais en enlevant l'effet aleatoire avec YEAR_rsf c'est correct. 0.992 (SD=0.010). 16 iterations sur 25 ont converge. 

kfold_crossvalid(data=data_calfvuln, nbiter=25, mod="presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+RISK_LOUPS+RISK_OURS+YEAR_no+RISK_LOUPS:YEAR_no+RISK_OURS:YEAR_no+(1|IDENT)",pourc=0.75,pres=data_calfvuln$presence,id=as.vector(data_calfvuln$IDENT),byid=T) # 0.870 (SD=0.091). 17 iterations sur 25 ont converge.


RISK_CALFVULN_H=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+RISK_LOUPS+RISK_OURS+YEAR_no+RISK_LOUPS:YEAR_no+RISK_OURS:YEAR_no+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_calfvuln,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))

kfold_crossvalid(data=data_calfvuln, nbiter=25, mod="presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+RISK_LOUPS+RISK_OURS+YEAR_no+RISK_LOUPS:YEAR_no+RISK_OURS:YEAR_no+(1|IDENT)+(1|YEAR_rsf)",pourc=0.75,pres=data_calfvuln$presence,id=as.vector(data_calfvuln$IDENT),byid=F)


##### ASSUMPTIONS

# Condition 1 : binarity of dep var (ok)
# Condition 2 : linear relationship between logit(y) and each ind var (ok)
# Condition 3 : absence of outliers
# Condition 4 : no colinearity (VIFs)


plot(RISK_CALFVULN_H) # Condition 3

RISK_CALFVULN_H_sans_int=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+RISK_LOUPS+RISK_OURS+YEAR_no+(1|IDENT),family=binomial,data=data_calfvuln,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE))) # Pour les VIFs, runner modele sans interactions

vif(RISK_CALFVULN_H_sans_int) # VIF MAX = 6.06 for RISK_OURS

RISK_CALFVULN_H_test=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_Perturb_0_5+L_Perturb_6_20+YEAR_no+(1|IDENT),family=binomial,data=data_calfvuln,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))

vif(RISK_CALFVULN_H_test) # VIF max = 1.71


##### Verification of frequency distributions of independent variables

hist(data_calfvuln$RISK_LOUPS)
hist(data_calfvuln$RISK_OURS)



############################################################################
################################# WINTER ###################################
############################################################################

# Import database

data_winter <- read_excel(file.choose(), 1)

data_winter$YEAR_rsf = data_winter$YEAR_suivi # recreate variable  YEAR_rsf in characters
data_winter$YEAR_rsf = as.character(data_winter$YEAR_rsf) 
str(data_winter)


sum(sum(data_winter$L_Decid_Mixt_Mature),
    sum(data_winter$L_OldMatForest),
    sum(data_winter$L_Other),
    sum(data_winter$L_Perturb_0_5),
    sum(data_winter$L_Perturb_6_20),
    sum(data_winter$L_Regeneration),
    sum(data_winter$L_Wetlands),
    sum(data_winter$L_YgMatForest))

essai1=subset(data_winter, L_YgMatForest==1)
essai2=subset(data_winter, L_OldMatForest==1)




##### Verify frequency distributions of independent variabless

data_winter_0 = subset(data_winter, presence==0)
data_winter_1 = subset(data_winter, presence==1)

hist(data_winter_0$RISK_LOUPS)
boxplot(data_winter_0$RISK_LOUPS)

hist(data_winter_1$RISK_LOUPS)
boxplot(data_winter_1$RISK_LOUPS)



##### Verification of frequency distributions of independent variables

hist(data_winter$RISK_LOUPS)
hist(data_winter$YEAR_no)
hist(data_winter$YEAR_rsf)


##### Verify that we have data for each levels of random effects

length(table(data_winter$IDENT_YEAR)) # 111 ID_YEAR

table(data_winter$IDENT,data_winter$YEAR_no) # No individual in problem


##### CANDIDATE MODELS

# REF CATEGORY : Perturb_0_5

# Model A (variable of wolf risk only)
RISK_WINTER_A=glmer(presence~RISK_LOUPS+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_winter,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))

# Model B (habitat classes only)
RISK_WINTER_B=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_OldMatForest+L_Perturb_6_20+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_winter,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))

# Model C (habitat and wolf risk)
RISK_WINTER_C=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_OldMatForest+L_Perturb_6_20+RISK_LOUPS+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_winter,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))

# Model D (habitat and interaction with wolf risk)
RISK_WINTER_D=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_OldMatForest+L_Perturb_6_20+RISK_LOUPS+YEAR_no+RISK_LOUPS:YEAR_no+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_winter,glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))


summary(RISK_WINTER_D)

AICc_WINTER = model.sel(RISK_WINTER_A,RISK_WINTER_B,RISK_WINTER_C,RISK_WINTER_D, rank = AICc)

AICc_WINTER = rownames_to_column(AICc_WINTER,var = "model")

write_xlsx(AICc_WINTER, path="AICc_WINTER.xlsx")

summary(RISK_WINTER_D)


##### BEST-RANKED MODEL

RISK_WINTER_D=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_OldMatForest+L_Perturb_6_20+RISK_LOUPS+YEAR_no+RISK_LOUPS:YEAR_no+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_winter)

summary(RISK_CALFVULN_H)

save(RISK_WINTER_D, file = "RISK_WINTER_D.RData") # function to save it
load("RISK_WINTER_D.RData") # function to load it

str(data_winter)


RISK_WINTER_D_coefs <- as.data.frame(coef(summary(RISK_WINTER_D)))
RISK_WINTER_D_coefs = rownames_to_column(RISK_WINTER_D_coefs,var = "variable")
CI_winter = as.data.frame(confint(RISK_WINTER_D,method="Wald"))
CI_winter = CI_winter[-c(1:2),]
RISK_WINTER_D_coefs$CI_2.5 = CI_winter$`2.5 %`
RISK_WINTER_D_coefs$CI_97.5 = CI_winter$`97.5 %`
write_xlsx(RISK_WINTER_D_coefs, path="RISK_WINTER_D_coefs.xlsx")


##### K-FOLD CROSS VALIDATION

RISK_WINTER_D=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_OldMatForest+L_Perturb_6_20+RISK_LOUPS+YEAR_no+RISK_LOUPS:YEAR_no+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_winter,control = glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE)))

kfold_crossvalid(data=data_winter, nbiter=15, mod="presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_OldMatForest+L_Perturb_6_20+RISK_LOUPS+YEAR_no+RISK_LOUPS:YEAR_no+(1|IDENT)+(1|YEAR_rsf)",pourc=0.75,pres=data_winter$presence,id=as.vector(data_winter$IDENT),byid=F) # 0.886 (SD=0.016). 13 iterations sur 15 ont converge, pas d'erreur, mas ca prend l'optimiseur pour faire converger le modele.

kfold_crossvalid(data=data_winter, nbiter=15, mod="presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_OldMatForest+L_Perturb_6_20+RISK_LOUPS+YEAR_no+RISK_LOUPS:YEAR_no+(1|IDENT)+(1|YEAR_rsf)",pourc=0.75,pres=data_winter$presence,id=as.vector(data_winter$IDENT),byid=T) # 0.832 (SD=0.087). 12 iterations sur 15 ont converge, pas d'erreur. 


##### ASSUMPTIONS

# Condition 1 : binarity of dep var (ok)
# Condition 2 : linear relationship between logit(y) and each ind var (ok)
# Condition 3 : absence of outliers
# Condition 4 : no colinearity (VIFs)

plot(RISK_WINTER_D) # Condition 3

RISK_WINTER_D_sans_int=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_OldMatForest+L_Perturb_6_20+RISK_LOUPS+YEAR_no+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_winter,control = glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE))) # Pour les VIFs, runner modele sans interactions

vif(RISK_WINTER_D_sans_int) # VIF MAX = 6.56 for oldmatforest. 5.62 for ygmatforest

RISK_WINTER_D_test=glmer(presence~L_Decid_Mixt_Mature+L_Other+L_Regeneration+L_Wetlands+L_YgMatForest+L_OldMatForest+L_Perturb_6_20+YEAR_no+(1|IDENT)+(1|YEAR_rsf),family=binomial,data=data_winter,control = glmerControl(optimizer = "optimx", calc.derivs = FALSE, optCtrl = list(method = "nlminb", starttests = FALSE, kkt = FALSE))) # Pour les VIFs, runner modele sans interactions

vif(RISK_WINTER_D_test) # VIF max = 5.24 for oldmatforest. 5.13 for ygmatforest.


##### Verification of frequency distributions for independent variables

hist(data_calving$RISK_LOUPS)
hist(data_spring$YEAR_no)







